@@ -1,5 +1,5 @@
 # Authors: Manpreet Singh <singhmnprt01@gmail.com>
-# customdnn Copyright (C) 2020 singhmnprt01@gmail.com  
+# customdnn Copyright (C) 2020 singhmnprt01@gmail.com
 # License: GNU GENERAL PUBLIC LICENSE
 
 import numpy as np
@@ -12,7 +12,6 @@ import sys
 import warnings
 
 
-
 class SplitData:
     """
      This class helps the user to split the data into train and test.
@@ -20,16 +19,16 @@ class SplitData:
 
     """
 
-    def split_train_test(self,x, y, test_percentage):
+    def split_train_test(self, x, y, test_percentage):
         """
          Parameters
         ----------
         x : dataframe
             Input feature set
-            
+
         y : dataframe(0,1)
             Target variable
-            
+
         test_percentage: int 
             Percentage of total data to be used as test
         """
@@ -55,9 +54,9 @@ class SplitData:
 class TrainingDeepNetwork:
     """
     The purpose if the class is to train the user defined neural network 
-    and return the updated set prameters(weight- w and bias- b)
+    and return the updated set parameters(weight- w and bias- b)
 
-    User needs to input x, y and certain set of hyperparamneters to create a custom Deep Neural Network
+    User needs to input x, y and certain set of hyperparameters to create a custom Deep Neural Network
 
     """
 
@@ -97,7 +96,7 @@ class TrainingDeepNetwork:
         return mini_batches
 
     def __dnn_preprocessing(self, x, y, batch_size, layer_nn):
-        """ It prepares the neural network architecture as per the user requirements and preprocesses the data to make it network ready. """
+        """ It prepares the neural network architecture as per the user requirements and pre-processes the data to make it network ready. """
 
         mini_batches = []
         cost_array = []
@@ -160,7 +159,7 @@ class TrainingDeepNetwork:
                     layer_nn, A_all, y_min, param, Z_all, beta1, beta2, gradient)
 
                 param = self.__param_update(dW_all, db_all, Vdw_corrected, Vdb_corrected,
-                                          Sdw_corrected, Sdb_corrected, param, alpha, nw_size, gradient)
+                                            Sdw_corrected, Sdb_corrected, param, alpha, nw_size, gradient)
 
             cost = cost/batch_size
             cost_array.append(cost)
@@ -168,9 +167,9 @@ class TrainingDeepNetwork:
             if(epoch % 100 == 0):
                 cost_epoch_array.append(cost)
 
-            incre = int(50.0 / epoch_num * i)
+            incre = int(50.0 / epoch_num * prog_bar)
             sys.stdout.write('\r')
-            if i != epoch_num - 1:
+            if prog_bar != epoch_num - 1:
                 sys.stdout.write('|%s%s%s%s| %d%%' % (
                     unitColor, '\033[7m' + ' '*incre + ' \033[27m', endColor, ' '*(49-incre), 2*incre))
             else:
@@ -382,54 +381,67 @@ class TrainingDeepNetwork:
 
     def train_network(self, x, y, learning_rate=.001, beta1=.9, beta2=.999, batch_size=32, network_size=3, gradient="Adam", epoch_num=1000, dropout_percentage=70):
         """
-        This is the main fucntion of the class which controls other paramount functions, process user input, 
+        This is the main function of the class which controls other paramount functions, process user input, 
         display cost function graphs and returns trained  set of weight and bias parameters.
-        
+
         Parameters
         ----------
         x : numpy array
-            Input feature set
-            
+            Input feature set data
+
         y : numpy array
             Target variable
-            
+
         learning_rate : float, default = .001
             The rate of learning at which the gradient steps will be taken to minimise the cost
-            
+
         beta1 : float, default = .9
             Beta constant for Gradient Descent Momentum Optimisation Algorithm
-            
+
         beta2 : float, default = .999
             Beta constant for Root Mean Square prop Optimisation Algorithm
-            
+
         batch_size : int, default = 32
             To create customised mini-batches to amplify the processing and improve model accuracy/generalisation/learning.
-            
+
         network_size : int, default = 3
             A custom variable to design the number of layer of your network. It is exclusive of input and output layer
-            
+
         gradient : string, default = "Adam"      
             Gradient Descent Optimisation algorithm choosing field. You can input any of the following three optimizers :-
                   GDM : Gradient Descent Momentum
                   RMSprop : Room Mean Square Prop
                   Adam : Adaptive Momentum Estimation
-                  
+
         epoch_num : int, default = 1000
             Number of epochs/iterations for the network. 
-          
+
         dropout_percentage : int, default = 70
             Percent of neurons to be fused.
+
+
+        Returns
+        -------
+        param : dict
+            parameter dictionary of trained network.
+
         """
 
         layer_nn = []
         # feeding the input layer neurons !
         layer_nn.append(int(x.shape[0]))
 
-        print("You have choosen the default network having  ",
-              network_size+1, " layers with ", network_size, " hidden layers.\n")
-        inp = input("If you didn't choose this netowrk size and wish to choose one \nPlease press Y and enter start over \n         #########  or  ######### \nPress N to continue entering the number of neurons for each layer \n")
+        if (int(network_size) == 3):
+            print("You have choosen the default network having  ",
+                  network_size+1, " layers with ", network_size, " hidden layers.\n")
 
-        if (inp == "Y" or inp == "y"):
+        else:
+            print("You have designed the network having  ",
+                  network_size+1, " layers with ", network_size, " hidden layers.\n")
+
+        inp = input("If you wish to update the network design, then Enter N to start over \n         #########  or  ######### \nEnter any other key to continue entering the number of neurons for each layer \n")
+
+        if (inp == "N" or inp == "n"):
             raise Exception(
                 'You exit the network as you wanted to choose different network arch !. Please start over ')
 
